.. _api-admin:

Admin
=====

.. automodule:: guardian.admin

Return to :ref:`api`.


.. admin:: GuardedModelAdmin

GuardedModelAdmin
-----------------

.. autoclass:: guardian.admin.GuardedModelAdmin
   :members:

